==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebNavbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavbarDescription } from "./WebNavbarDescription";
/**
 * @hidden
 */
var WebNavbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNavbarDescriptionMetadata, _super);
    function WebNavbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavbarDescriptionMetadata.b = function (a) {
        if (WebNavbarDescriptionMetadata.a == null) {
            WebNavbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavbarDescriptionMetadata.c(WebNavbarDescriptionMetadata.a);
        }
        if (a.g(WebNavbarDescriptionMetadata.a)) {
            return;
        }
        a.s(WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Navbar");
    };
    WebNavbarDescriptionMetadata.d = function (a) {
        WebNavbarDescriptionMetadata.b(a);
        a.u("WebNavbar", function () { return new WebNavbarDescription(); });
        a.t("WebNavbar", WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.$t = markType(WebNavbarDescriptionMetadata, 'WebNavbarDescriptionMetadata');
    WebNavbarDescriptionMetadata.a = null;
    return WebNavbarDescriptionMetadata;
}(Base));
export { WebNavbarDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebNavbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavbarDescription } from "./WebNavbarDescription";
/**
 * @hidden
 */
var WebNavbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNavbarDescriptionMetadata, _super);
    function WebNavbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavbarDescriptionMetadata.b = function (a) {
        if (WebNavbarDescriptionMetadata.a == null) {
            WebNavbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavbarDescriptionMetadata.c(WebNavbarDescriptionMetadata.a);
        }
        if (a.j(WebNavbarDescriptionMetadata.a)) {
            return;
        }
        a.y(WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Navbar");
        a.item("__tagNameWC", "String:igc-navbar");
    };
    WebNavbarDescriptionMetadata.d = function (a) {
        WebNavbarDescriptionMetadata.b(a);
        a.aa("WebNavbar", function () { return new WebNavbarDescription(); });
        a.z("WebNavbar", WebNavbarDescriptionMetadata.a);
    };
    WebNavbarDescriptionMetadata.$t = markType(WebNavbarDescriptionMetadata, 'WebNavbarDescriptionMetadata');
    WebNavbarDescriptionMetadata.a = null;
    return WebNavbarDescriptionMetadata;
}(Base));
export { WebNavbarDescriptionMetadata };
